Name:           mailfront-plugin-check-dnsbl
Summary:        A mailfront plugin to provide DNSBL/DNSWL checking of sender's IP address and to defer, reject or accept mails based on its check.
Version:        0.02
Release:        1%{?dist}
License:        GPL
Group:          Utilities/System
URL:            http://choon.net/mailfront-plugin-check-dnsbl.php
Source:         http://choon.net/opensource/mailfront-plugin-check-dnsbl-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  gcc >= 3.4.6
BuildRequires:  make
BuildRequires:  bglibs-devel >= 1.104
BuildRequires:  mailfront-devel >= 2.00
BuildRequires:  libowfat-devel >= 0.29
Requires:       bglibs >= 1.104
Requires:       mailfront >= 2.00
Requires:       ucspi-tcp >= 0.88
Requires:       libowfat-shared >= 0.29


%description
Plugin: check-dnsbl

This plugin provides DNSBL/DNSWL checking of sender's IP address and
to defer, reject or accept mails based on its check.  This plugin will add
its checking results to each mail message header for all mails accepted
depending on environment variables configurations.

(1).  If $DNSBL_CHECK_SKIP is set, this plugin will be skipped.

(2).  If $RELAYCLIENT is set, add to message header and skip the remaining
      checks.  Example of message header added:

      X-DNSBL-Check-Result: SKIPPED: $RELAYCLIENT is set for 1.2.3.4

(3).  If sender is authenticated, add to message header and skip the
      remaining checks.  Example of message header added:

      X-DNSBL-Check-Result: SKIPPED: authenticated user from 1.2.3.4

(4).  If $PROTO is TCP6 or ${PROTO}REMOTEIP contain ":" character, add to
      message header and skip the remaining checks. Example of message
      header added:

      X-DNSBL-Check-Result: SKIPPED: $PROTO is TCP6 or is non-IPv4 for ${PROTO}REMOTEIP

      ${PROTO}REMOTEIP will be parsed.

(5).  If $RBLSMTPD is set and empty, add to message header and skip the
      remaining checks.  If $RBLSMTPD is set and not empty, the reply code
      is set to 553 if the first character of $RBLSMTPD is "-" otherwise
      the reply code is set to 451.  The reply message will be copied from
      $RBLSMTPD and will skip "-" if it is the starting character of
      $RBLSMTPD.  Examples of smtp.rules for tcprules:

      1.1.1.1:allow,RBLSMTPD=""
      2.2.2.2:allow,RBLSMTPD="-Your IP is listed in our denied list."
      3.3.3.3:allow,RBLSMTPD="Your IP is listed in our denied list."

      The above will cause this plugin to accept mails from IP 1.1.1.1,
      reject mails from IP 2.2.2.2 and defer mails from IP 3.3.3.3.  Below
      are the reply to sender's IP 2.2.2.2 and 3.3.3.3 respectively:

      553 Your IP is listed in our denied list.
      451 Your IP is listed in our denied list.

      Example of message header added for IP 1.1.1.1:

      X-DNSBL-Check-Result: SKIPPED: $RBLSMTPD is set and empty for 1.1.1.1

(6).  $RWLDOMAINS is the list of servers/domains to check for whitelisting
      (DNSWL).  If $RWLDOMAINS is set and not empty, the domains listed
      will be used for DNSWL checking.  Each domain needs to be seperated
      with a SPACE or a colon ":".

(7).  $RWLDOMAINSFILE is a file with list of servers/domains to check for
      whitelisting (DNSWL).   This will only be used if $RWLDOMAINS is not
      set.  i.e. copy the content into $RWLDOMAINS.
      If $RWLDOMAINSFILE not set will default to
      /var/qmail/control/rwldomains which is a define constant of
      DNSBL_RWLDOMAINS_FILE.  Format in this file is one domain per line.
      Lines started with # are ignored.

(8).  $RBLDOMAINS is the list of servers/domains to check for blacklisting
      (DNSBL).  If $RBLDOMAINS is set and not empty, the domains listed
      will be used for DNSBL checking.  Each domain needs to be seperated
      with a SPACE or a colon ":".

(9).  $RBLDOMAINSFILE is a file with list of servers/domains to check for
      blacklisting (DNSBL).   This will only be used if $RBLDOMAINS is not
      set.  i.e. copy the content into $RBLDOMAINS.
      If $RBLDOMAINSFILE not set will default to
      /var/qmail/control/rbldomains which is a define constant of
      DNSBL_RBLDOMAINS_FILE.  Format in this file is one domain per line.
      Lines started with # are ignored.

(10). If $RWLDOMAINS and $RBLDOMAINS not set or empty, add to mail
      message header and skip the DNSWL/DNSBL checks.  Example of mail
      header added:

      X-DNSBL-Check-Result: SKIPPED: $RWLDOMAINS and $RBLDOMAINS not set or empty for 1.2.3.4

(11). If $DNSBL_CHECK_REJECT is set, sender will be rejected with reply
      code 553 if sender's IP is listed in one of the $RBLDOMAINS domain.
      If sender's IP is listed in one of the $RWLDOMAINS domains, mail
      message will be accepted as this plugin take preference of
      $RWLDOMAINS domains then $RBLDOMAINS domains.

(12). If $DNSBL_CHECK_DEFER is set, sender will be rejected with reply
      code 451 if sender's IP is listed in one of the $RBLDOMAINS domain.
      If sender's IP is listed in one of the $RWLDOMAINS domains, mail
      message will be accepted as this plugin take preference of
      $RWLDOMAINS domains then $RBLDOMAINS domains.
      NOTE: $DNSBL_CHECK_REJECT take preference of $DNSBL_CHECK_DEFER.

NOTE: For (11) and (12), mails that are rejected/deferred due to blacklist,
      this plugin will use the first listed domain's TXT record in its
      reply message.  If there isn't such will default to the following:

      Sorry, your ip ${PROTO}REMOTEIP is listed in one or more of the DNSBL: $RBLDOMAINS

      The ${PROTO}REMOTEIP and $RBLDOMAINS will be parsed accordingly.

      If sender's IP is listed in one of the $RWLDOMAINS domain, instead of
      rejecting/deferring mail, mail message will be accepted and all the
      DNSWL/DNSBL check results will be added to each mail message header.

(13). If $DNSBL_CHECK_REJECT and $DNSBL_CHECK_DEFER not set, all mail
      message will be accepted with DNSWL/DNSBL check results added to each
      mail message header.

(14). If $DNSBL_CHECK_VERBOSE is set, this plugin will log its checking to
      stderr.

IMPORTANT: This plugin is written for and tested with mailfront version 2.00
           and might work with earlier version.


%prep
%setup -q
make rpmenv
echo %{_libdir}/mailfront > conf-modules


%build
make


%install
rm -fr %{buildroot}
mkdir -p %{buildroot}/%{_libdir}/mailfront
install -m0755 plugin-check-dnsbl.so %{buildroot}/%{_libdir}/mailfront/


%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root)
%doc README COPYING CHANGES plugin-check-dnsbl.html
%{_libdir}/mailfront/plugin-check-dnsbl.so

%changelog

* Sun Jun 23 2013 Giam Teck Choon <choonrpms@choon.net> - 0.02-1
- Fix bug in defer/reject message being corrupted due to freeing not suppose
  to free tmpstr by using global str estr instead
- Coding style change to 2 SPACING instead of using TAB

* Mon Jun 10 2013 Giam Teck Choon <choonrpms@choon.net> - 0.01-1
- Initial Release
